==> ATGoogleMaps-0.4.1.tar.gz: ATGoogleMaps/Extensions/Install.py <==
from Products.CMFCore.utils import getToolByName
from Products.CMFFormController.FormAction import FormActionKey
from Products.Archetypes.Extensions.utils import installTypes
from Products.Archetypes.Extensions.utils import install_subskin
from Products.Archetypes.public import listTypes

from StringIO import StringIO

from Products.CMFDynamicViewFTI.migrate import migrateFTIs

from Products.ATGoogleMaps.config import *

def install(self):
    """Install ATGoogleMaps: Install content types, skin layer, install the
    stylesheet, set up global properties, enable the portal factory and
    set up form controller actions for the widget actions
    """

    out = StringIO()

    print >> out, "Installing ATGoogleMaps"

    # Install types
    classes = listTypes(PROJECTNAME)
    installTypes(self, out,
                 classes,
                 PROJECTNAME)
    print >> out, "Installed types"

    # Install skin
    install_subskin(self, out, GLOBALS)
    print >> out, "Installed skin"

    # Migrate FTI, to make sure we get the necessary infrastructure for the
    # 'display' menu to work.
    migrated = migrateFTIs(self, product=PROJECTNAME)
    print >>out, "Switched to DynamicViewFTI: %s" % ', '.join(migrated)

    # Enable portal_factory
    factory = getToolByName(self, 'portal_factory')
    types = factory.getFactoryTypes().keys()
    if 'GMap' not in types:
        types.append('GMap')
        factory.manage_setPortalFactoryTypes(listOfTypeIds = types)

    print >> out, "Added ATGoogleMaps to portal_factory"

    portal_props = getToolByName(self, 'portal_properties')
    siteProperties = getattr(portal_props, 'site_properties')
    navtreeProperties = getattr(portal_props, 'navtree_properties')

    # Add to default_page_types
    defaultPageTypes = list(siteProperties.getProperty('default_page_types'))
    if 'GMap' not in defaultPageTypes:
        defaultPageTypes.append('GMap')
        siteProperties.manage_changeProperties(default_page_types = defaultPageTypes)

    # Add property sheet
    if not hasattr(portal_props, PROPERTY_SHEET):
        portal_props.addPropertySheet(PROPERTY_SHEET, 'ATGoogleMaps properties')
    props = getattr(portal_props, PROPERTY_SHEET)
    if not hasattr(props, 'api_key'):
        props._setProperty('api_key', '', 'string')

    # Add to parentMetaTypesNotToQuery
    #parentMetaTypesNotToQuery = list(navtreeProperties.getProperty('parentMetaTypesNotToQuery'))
    #if 'GMap' not in parentMetaTypesNotToQuery:
    #    parentMetaTypesNotToQuery.append('GMap')
    #navtreeProperties.manage_changeProperties(parentMetaTypesNotToQuery = parentMetaTypesNotToQuery)

    install_configlet(self, out)

    return out.getvalue()

def install_configlet(self, out):
    try:
	portal_conf = getToolByName(self, 'portal_controlpanel')
    except AttributeError:
	print >>out, "Configlet could not be installed"
    try:
	portal_conf.registerConfiglet('%sSettings' % PROJECTNAME,
				      '%s Settings' % PROJECTNAME,
				      'string:${portal_url}/prefs_gmap_form',
				      '',
				      'Manage Portal',
				      'Products',
				      1,
				      PROJECTNAME,
				      'gmap_icon.gif',
				      '',
				      None,
				      )
    except KeyError:
        pass # Get KeyError when registering duplicate configlet.

def uninstall(self, reinstall):
    out = StringIO()

    if not reinstall:
        print >> out, "Uninstalling ATGoogleMaps"

        portal_props = getToolByName(self, 'portal_properties')
        siteProperties = getattr(portal_props, 'site_properties')
        navtreeProperties = getattr(portal_props, 'navtree_properties')

        # Remove to default_page_types
        defaultPageTypes = list(siteProperties.getProperty('default_page_types'))
        if 'GMap' in defaultPageTypes:
            defaultPageTypes.remove('GMap')
            siteProperties.manage_changeProperties(default_page_types = defaultPageTypes)

        # Remove property sheet
        if hasattr(portal_props, PROPERTY_SHEET):
            portal_props.manage_delObjects(PROPERTY_SHEET)

    # remove the configlet from the portal control panel
    configTool = getToolByName(self, 'portal_controlpanel', None)
    if configTool:
        configTool.unregisterConfiglet('%sSettings' % PROJECTNAME)
        print >> out, 'Removed ATGoogleMaps configlet'

    return out.getvalue()

==> ATGoogleMaps-0.5.1.tar.gz: ATGoogleMaps/Extensions/Install.py <==
from Products.CMFCore.utils import getToolByName
from Products.CMFFormController.FormAction import FormActionKey
from Products.Archetypes.Extensions.utils import installTypes
from Products.Archetypes.Extensions.utils import install_subskin
from Products.Archetypes.public import listTypes

from StringIO import StringIO

from Products.CMFDynamicViewFTI.migrate import migrateFTIs

from Products.ATGoogleMaps.config import *

def install(self):
    """Install ATGoogleMaps: Install content types, skin layer, install the
    stylesheet, set up global properties, enable the portal factory and
    set up form controller actions for the widget actions
    """

    out = StringIO()

    print >> out, "Installing ATGoogleMaps"

    # Install types
    classes = listTypes(PROJECTNAME)
    installTypes(self, out,
                 classes,
                 PROJECTNAME)
    print >> out, "Installed types"

    # Install skin
    install_subskin(self, out, GLOBALS)
    print >> out, "Installed skin"

    # Migrate FTI, to make sure we get the necessary infrastructure for the
    # 'display' menu to work.
    migrated = migrateFTIs(self, product=PROJECTNAME)
    print >>out, "Switched to DynamicViewFTI: %s" % ', '.join(migrated)

    # Enable portal_factory
    factory = getToolByName(self, 'portal_factory')
    types = factory.getFactoryTypes().keys()
    for add_type in ('GMap', 'GMarker'):
        if add_type not in types:
            types.append(add_type)
            factory.manage_setPortalFactoryTypes(listOfTypeIds = types)

    print >> out, "Added ATGoogleMaps contents to portal_factory"

    portal_props = getToolByName(self, 'portal_properties')
    siteProperties = getattr(portal_props, 'site_properties')
    navtreeProperties = getattr(portal_props, 'navtree_properties')

    # Add to default_page_types
    defaultPageTypes = list(siteProperties.getProperty('default_page_types'))
    if 'GMap' not in defaultPageTypes:
        defaultPageTypes.append('GMap')
        siteProperties.manage_changeProperties(default_page_types = defaultPageTypes)

    # Add property sheet
    if not hasattr(portal_props, PROPERTY_SHEET):
        portal_props.addPropertySheet(PROPERTY_SHEET, 'ATGoogleMaps properties')
    props = getattr(portal_props, PROPERTY_SHEET)
    if not hasattr(props, 'api_key'):
        props._setProperty('api_key', '', 'string')

    # Add to parentMetaTypesNotToQuery
    #parentMetaTypesNotToQuery = list(navtreeProperties.getProperty('parentMetaTypesNotToQuery'))
    #if 'GMap' not in parentMetaTypesNotToQuery:
    #    parentMetaTypesNotToQuery.append('GMap')
    #navtreeProperties.manage_changeProperties(parentMetaTypesNotToQuery = parentMetaTypesNotToQuery)

    install_configlet(self, out)

    return out.getvalue()

def install_configlet(self, out):
    try:
	portal_conf = getToolByName(self, 'portal_controlpanel')
    except AttributeError:
	print >>out, "Configlet could not be installed"
    try:
	portal_conf.registerConfiglet('%sSettings' % PROJECTNAME,
				      '%s Settings' % PROJECTNAME,
				      'string:${portal_url}/prefs_gmap_form',
				      '',
				      'Manage Portal',
				      'Products',
				      1,
				      PROJECTNAME,
				      'gmap_icon.gif',
				      '',
				      None,
				      )
    except KeyError:
        pass # Get KeyError when registering duplicate configlet.

def uninstall(self, reinstall):
    out = StringIO()

    if not reinstall:
        print >> out, "Uninstalling ATGoogleMaps"

        portal_props = getToolByName(self, 'portal_properties')
        siteProperties = getattr(portal_props, 'site_properties')
        navtreeProperties = getattr(portal_props, 'navtree_properties')

        # Remove to default_page_types
        defaultPageTypes = list(siteProperties.getProperty('default_page_types'))
        if 'GMap' in defaultPageTypes:
            defaultPageTypes.remove('GMap')
            siteProperties.manage_changeProperties(default_page_types = defaultPageTypes)

        # Remove property sheet
        if hasattr(portal_props, PROPERTY_SHEET):
            portal_props.manage_delObjects(PROPERTY_SHEET)

    # remove the configlet from the portal control panel
    configTool = getToolByName(self, 'portal_controlpanel', None)
    if configTool:
        configTool.unregisterConfiglet('%sSettings' % PROJECTNAME)
        print >> out, 'Removed ATGoogleMaps configlet'

    return out.getvalue()
